@@ -1,17 +1,17 @@
 enc_in = {
-		"&01": "<",
-		"&02": " ",
-		"&03": "=",
-		"&04": "\n",
-		"&05": "\t"
-	}
+		"{LEFT}": "<",
+		"{SPACE}": " ",
+		"{EQUAL}": "=",
+		"{NL}": "\n",
+		"{TAB}": "\t"
+}
 
 enc_out = {
-	"<": "&01",
-	" ": "&02",
-	"=": "&03",
-	"\n": "&04",
-	"\t": "&05"
+	"<": "{LEFT}",
+	" ": "{SPACE}",
+	"=": "{EQUAL}",
+	"\n": "{NL}",
+	"\t": "{TAB}"
 }
 
 def create_node(node: dict):
